



bsondump --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
mongodump --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
mongorestore --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
mongoimport --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
mongoexport --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
mongostat --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
mongotop --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
mongofiles --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
